==> mantra.3.3.0.zip: mantra/admin/defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

	"mantra_db" => "1.0",

	"mantra_side" => "2cSr",
	"mantra_dimselect" => 'Absolute',
	"mantra_sidewidth" => 800,
	"mantra_sidebar" => 340,
	"mantra_sidewidthRel" => 60,
	"mantra_sidebarRel" => 20,
	"mantra_mobile" => "Enable",
	"mantra_zoom" => 0,
	"mantra_hcontain" => "",

	"mantra_frontpage" => "Disable",
	"mantra_frontposts" => "Enable",
	"mantra_frontpostscount" => 5,
	"mantra_menualign" => "left",
	"mantra_fpsliderwidth" => "1050",
	"mantra_fpsliderheight" => "450",
	"mantra_fpslideranim" => "random",
	"mantra_fpsliderborderwidth" => "20",
	"mantra_fpsliderbordercolor" => "#111111",
	"mantra_fpslidertime" => "750",
	"mantra_fpsliderpause" => "5000",
	"mantra_fpslidernav" => "Bullets",
	"mantra_fpsliderarrows" => "Visible on Hover",

	"mantra_slideShortcode" => "",
	"mantra_slideType" => "Custom Slides",
	"mantra_slideCateg" => "",
	"mantra_slideNumber" => "3",
	"mantra_slideSpecific" => "",

	"mantra_sliderimg1" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-1.jpg",
	"mantra_slidertitle1" => "This is the caption title",
	"mantra_slidertext1" => "Maecenas mauris ante, mollis ac semper in, laoreet ac augue. Nunc ut turpis ipsum. Phasellus fringilla commodo tortor eu imperdiet. Etiam vehicula mollis pulvinar. In vestibulum eros et elit vehicula, eu egestas arcu feugiat. Lorem ipsum dolor sit amet, consectetur adipiscing.",
	"mantra_sliderlink1" => "",
	"mantra_sliderimg2" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-2.jpg",
	"mantra_slidertitle2" => "This is yet another caption title",
	"mantra_slidertext2" => 'Phasellus sit amet diam a metus iaculis sollicitudin. Nulla sed risus quis justo malesuada <a href="#">elementum</a> ut nulla eget leo maximus. Proin maximus dolor vel mauris volutpat blandit. Mauris urna nunc, pellentesque vel mauris vitae, convallis rutrum felis.',
	"mantra_sliderlink2" => "",
	"mantra_sliderimg3" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-3.jpg",
	"mantra_slidertitle3" => "A third example",
	"mantra_slidertext3" => "Phasellus non sagittis nibh. <em>Curabitur</em> quis lacus congue magna dapibus elementum. Nulla eu nulla est. Cras faucibus orci ante, vel sollicitudin quam lacinia gravida. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus vel ligula efficitur massa condimentum consequat aliquam at lectus. Duis pellentesque, ante sed mattis tincidunt.",
	"mantra_sliderlink3" => "",
	"mantra_sliderimg4" => "",
	"mantra_slidertitle4" => "",
	"mantra_slidertext4" => "",
	"mantra_sliderlink4" => "",
	"mantra_sliderimg5" => "",
	"mantra_slidertitle5" => "",
	"mantra_slidertext5" => "",
	"mantra_sliderlink5" => "",

	"mantra_nrcolumns" => "3",
	"mantra_colimageheight" => "215",
	"mantra_columnreadmore" => "Read more",

	"mantra_columnimg1" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-1.jpg",
	"mantra_columntitle1" => "Customizable",
	"mantra_columntext1" => "Aenean ut tempus quam, vitae ornare tellus. Suspendisse ligula nisi, vestibulum vitae suscipit nec, ornare eu lorem. Vestibulum tempor suscipit lacus nec vestibulum. Nullam convallis odio.",
	"mantra_columnlink1" => "",
	"mantra_columnimg2" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-2.jpg",
	"mantra_columntitle2" => "HTML5 and CSS3",
	"mantra_columntext2" => 'Phasellus sit amet diam a metus iaculis sollicitudin. Nulla sed risus quis justo malesuada <a href="#">elementum</a> ut nulla eget leo maximus. Proin maximus dolor vel mauris volutpat blandit.',
	"mantra_columnlink2" => "",
	"mantra_columnimg3" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-3.jpg",
	"mantra_columntitle3" => "Responsive",
	"mantra_columntext3" => "Phasellus non sagittis nibh. <em>Curabitur</em> quis lacus congue magna dapibus elementum. Etiam non pellentesque orci. Mauris urna nunc, pellentesque vel mauris vitae, convallis rutrum felis.",
	"mantra_columnlink3" => "",
	"mantra_columnimg4" => "",
	"mantra_columntitle4" => "",
	"mantra_columntext4" => "",
	"mantra_columnlink4" => "",

	"mantra_fronttext1" => "",
	"mantra_fronttext2" => "",
	"mantra_fronttitlecolor" => "#333333",
	"mantra_fronttext3" => "Phasellus hendrerit feugiat sollicitudin. Proin accumsan lacus ac dui pulvinar, ut gravida enim feugiat. Pellentesque semper faucibus varius. Nunc gravida, neque ac bibendum placerat, magna nisl consequat mi, nec egestas enim erat sed lacus. Quisque id ipsum in augue finibus euismod in eu diam. Sed vulputate mollis lectus, sit amet semper eros dictum quis. Vivamus nisl eros, facilisis facilisis orci ac, iaculis consequat justo. ",
	"mantra_fronttext4" => "",

	"mantra_fronthideheader" => "",
	"mantra_fronthidemenu" => "",
	"mantra_fronthidewidget" => "",
	"mantra_fronthidefooter" => "",
	"mantra_fronthideback" => "",

	"mantra_hheight" => "125",
	"mantra_hcenter" => "",
	"mantra_hratio" => "",
	"mantra_menurounded" => "Enable",
	"mantra_logoupload" => "",
	"mantra_siteheader" => "Site Title and Description",
	"mantra_headermargintop" => "30",
	"mantra_headermarginleft" => "30",

	"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
	"mantra_googlefont" => 'Open Sans:400,700',
	"mantra_googlefont2" => '',
	"mantra_fontsize" => "15px",
	"mantra_fonttitle" => 'Default',
	"mantra_googlefonttitle" => 'Merriweather:400,700',
	"mantra_googlefonttitle2" => '',
	"mantra_headfontsize" => "Default",
	"mantra_fontside" => 'Default',
	"mantra_googlefontside" => 'Open Sans:400,700',
	"mantra_googlefontside2" => '',
	"mantra_sidefontsize" => "Default",
	"mantra_fontsubheader" => 'Default',
	"mantra_googlefontsubheader" => 'Merriweather:400,700',
	"mantra_googlefontsubheader2" => '',
	"mantra_textalign" => "Default",
	"mantra_parmargin" => "1.5em",
	"mantra_parindent" => "0px",
	"mantra_headerindent" => "Disable",
	"mantra_lineheight" => "Default",
	"mantra_wordspace" => "Default",
	"mantra_letterspace" => "Default",

	"mantra_contentbg" => "#FFFFFF",
	"mantra_menubg" => "#FAFAFA",
	"mantra_s1bg" => "",
	"mantra_s2bg" => "",
	"mantra_backcolor" => "#444444",
	"mantra_headercolor" => "#333333",
	"mantra_prefootercolor" => "#222222",
	"mantra_footercolor" => "#171717",
	"mantra_titlecolor" => "#0D85CC",
	"mantra_descriptioncolor" => "#999999",
	"mantra_contentcolor" => "#555555",
	"mantra_linkscolor" => "#0D85CC",
	"mantra_hovercolor" => "#12a7ff",
	"mantra_headtextcolor" => "#444444",
	"mantra_headtexthover" => "#000000",
	"mantra_sideheadbackcolor" => "#444444",
	"mantra_sideheadtextcolor" => "#FFFFFF",

	"mantra_footerheader" => "#FFFFFF",
	"mantra_footertext" => "#666666",
	"mantra_footerhover" => "#888888",

	"mantra_breadcrumbs" => "Disable",
	"mantra_pagination" => "Enable",
	"mantra_caption" => "Light",
	"mantra_image" => "None",
	"mantra_pin" => "Pin2",
	"mantra_sidebullet" => "arrow_white",
	"mantra_metaback" => "Gray",
	"mantra_postseparator" => "Hide",
	"mantra_contentlist" => "Show",
	"mantra_pagetitle" => "Show",
	"mantra_categtitle" => "Show",
	"mantra_tables" => "Disable",
	"mantra_backtop" => "Enable",
	"mantra_comtext" => "Show",
	"mantra_comclosed" => "Hide everywhere",
	"mantra_comoff" => "Show",

	"mantra_postcomlink" => "Show",
	"mantra_postdate" => "Show",
	"mantra_posttime" => "Hide",
	"mantra_postauthor" => "Show",
	"mantra_postcateg" => "Show",
	"mantra_posttag" => "Show",
	"mantra_postbook" => "Show",
	"mantra_postmetas" => "Show",

	"mantra_excerpthome" => "Excerpt",
	"mantra_excerptsticky" => "Full Post",
	"mantra_excerptarchive" => "Excerpt",
	"mantra_excerptwords" => "50",
	"mantra_magazinelayout" => "Disable",
	"mantra_excerptdots" => "...",
	"mantra_excerptcont" => " Continue reading",
	"mantra_excerpttags" => "Disable",

	"mantra_fpost" => "Enable",
	"mantra_fpostlink" => "1",
	"mantra_fauto" => "Disable",
	"mantra_falign" => "Left",
	"mantra_fwidth" => "250",
	"mantra_fheight" => "150",
	"mantra_fcrop" => "",
	"mantra_fheader" => "Disable",

	"mantra_social1" => "Facebook",
	"mantra_social2" => "https://www.facebook.com/Profile_or_Page",
	"mantra_social3" => "Twitter",
	"mantra_social4" => "https://twitter.com/username",
	"mantra_social5" => "RSS",
	"mantra_social6" => "http://mydomain.tld/feed/",
	"mantra_social7" => "",
	"mantra_social8" => "",
	"mantra_social9" => "",
	"mantra_social10" => "",
	"mantra_socialsdisplay0" => "1",
	"mantra_socialsdisplay1" => "",
	"mantra_socialsdisplay2" => "1",
	"mantra_socialsdisplay3" => "1",

	"mantra_copyright" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla massa diam, tempus a finibus et, euismod nec arcu. Praesent ultrices massa at molestie facilisis.",
	"mantra_customcss" => "/* Mantra Custom CSS */  ",
	"mantra_customjs" => "",
	"mantra_editorstyle" => 1,
	
);

// FIN

==> mantra.3.3.2.zip: mantra/admin/defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

	"mantra_db" => "1.0",

	"mantra_side" => "2cSr",
	"mantra_dimselect" => 'Absolute',
	"mantra_sidewidth" => 800,
	"mantra_sidebar" => 340,
	"mantra_sidewidthRel" => 60,
	"mantra_sidebarRel" => 20,
	"mantra_mobile" => "Enable",
	"mantra_zoom" => 0,
	"mantra_hcontain" => "",

	"mantra_frontpage" => "Disable",
	"mantra_frontposts" => "Enable",
	"mantra_frontpostscount" => 5,
	"mantra_menualign" => "left",
	"mantra_fpsliderwidth" => "1050",
	"mantra_fpsliderheight" => "450",
	"mantra_fpslideranim" => "random",
	"mantra_fpsliderborderwidth" => "20",
	"mantra_fpsliderbordercolor" => "#111111",
	"mantra_fpslidertime" => "750",
	"mantra_fpsliderpause" => "5000",
	"mantra_fpslidernav" => "Bullets",
	"mantra_fpsliderarrows" => "Visible on Hover",

	"mantra_slideShortcode" => "",
	"mantra_slideType" => "Custom Slides",
	"mantra_slideCateg" => "",
	"mantra_slideNumber" => "3",
	"mantra_slideSpecific" => "",

	"mantra_sliderimg1" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-1.jpg",
	"mantra_slidertitle1" => "This is the caption title",
	"mantra_slidertext1" => "Maecenas mauris ante, mollis ac semper in, laoreet ac augue. Nunc ut turpis ipsum. Phasellus fringilla commodo tortor eu imperdiet. Etiam vehicula mollis pulvinar. In vestibulum eros et elit vehicula, eu egestas arcu feugiat. Lorem ipsum dolor sit amet, consectetur adipiscing.",
	"mantra_sliderlink1" => "",
	"mantra_sliderimg2" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-2.jpg",
	"mantra_slidertitle2" => "This is yet another caption title",
	"mantra_slidertext2" => 'Phasellus sit amet diam a metus iaculis sollicitudin. Nulla sed risus quis justo malesuada <a href="#">elementum</a> ut nulla eget leo maximus. Proin maximus dolor vel mauris volutpat blandit. Mauris urna nunc, pellentesque vel mauris vitae, convallis rutrum felis.',
	"mantra_sliderlink2" => "",
	"mantra_sliderimg3" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-slider-3.jpg",
	"mantra_slidertitle3" => "A third example",
	"mantra_slidertext3" => "Phasellus non sagittis nibh. <em>Curabitur</em> quis lacus congue magna dapibus elementum. Nulla eu nulla est. Cras faucibus orci ante, vel sollicitudin quam lacinia gravida. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus vel ligula efficitur massa condimentum consequat aliquam at lectus. Duis pellentesque, ante sed mattis tincidunt.",
	"mantra_sliderlink3" => "",
	"mantra_sliderimg4" => "",
	"mantra_slidertitle4" => "",
	"mantra_slidertext4" => "",
	"mantra_sliderlink4" => "",
	"mantra_sliderimg5" => "",
	"mantra_slidertitle5" => "",
	"mantra_slidertext5" => "",
	"mantra_sliderlink5" => "",

	"mantra_nrcolumns" => "3",
	"mantra_colimageheight" => "215",
	"mantra_columnreadmore" => "Read more",

	"mantra_columnimg1" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-1.jpg",
	"mantra_columntitle1" => "Customizable",
	"mantra_columntext1" => "Aenean ut tempus quam, vitae ornare tellus. Suspendisse ligula nisi, vestibulum vitae suscipit nec, ornare eu lorem. Vestibulum tempor suscipit lacus nec vestibulum. Nullam convallis odio.",
	"mantra_columnlink1" => "",
	"mantra_columnimg2" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-2.jpg",
	"mantra_columntitle2" => "HTML5 and CSS3",
	"mantra_columntext2" => 'Phasellus sit amet diam a metus iaculis sollicitudin. Nulla sed risus quis justo malesuada <a href="#">elementum</a> ut nulla eget leo maximus. Proin maximus dolor vel mauris volutpat blandit.',
	"mantra_columnlink2" => "",
	"mantra_columnimg3" => esc_url( get_template_directory_uri() )."/resources/images/slider/mantra-column-3.jpg",
	"mantra_columntitle3" => "Responsive",
	"mantra_columntext3" => "Phasellus non sagittis nibh. <em>Curabitur</em> quis lacus congue magna dapibus elementum. Etiam non pellentesque orci. Mauris urna nunc, pellentesque vel mauris vitae, convallis rutrum felis.",
	"mantra_columnlink3" => "",
	"mantra_columnimg4" => "",
	"mantra_columntitle4" => "",
	"mantra_columntext4" => "",
	"mantra_columnlink4" => "",

	"mantra_fronttext1" => "",
	"mantra_fronttext2" => "",
	"mantra_fronttitlecolor" => "#333333",
	"mantra_fronttext3" => "Phasellus hendrerit feugiat sollicitudin. Proin accumsan lacus ac dui pulvinar, ut gravida enim feugiat. Pellentesque semper faucibus varius. Nunc gravida, neque ac bibendum placerat, magna nisl consequat mi, nec egestas enim erat sed lacus. Quisque id ipsum in augue finibus euismod in eu diam. Sed vulputate mollis lectus, sit amet semper eros dictum quis. Vivamus nisl eros, facilisis facilisis orci ac, iaculis consequat justo. ",
	"mantra_fronttext4" => "",

	"mantra_fronthideheader" => "",
	"mantra_fronthidemenu" => "",
	"mantra_fronthidewidget" => "",
	"mantra_fronthidefooter" => "",
	"mantra_fronthideback" => "",

	"mantra_hheight" => "125",
	"mantra_hcenter" => "",
	"mantra_hratio" => "",
	"mantra_menurounded" => "Enable",
	"mantra_logoupload" => "",
	"mantra_siteheader" => "Site Title and Description",
	"mantra_headermargintop" => "30",
	"mantra_headermarginleft" => "30",

	"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
	"mantra_googlefont" => 'Open Sans:400,700',
	"mantra_googlefont2" => '',
	"mantra_fontsize" => "15px",
	"mantra_fonttitle" => 'font-general',
	"mantra_googlefonttitle" => 'Merriweather:400,700',
	"mantra_googlefonttitle2" => '',
	"mantra_headfontsize" => "Default",
	"mantra_fontside" => 'font-general',
	"mantra_googlefontside" => 'Open Sans:400,700',
	"mantra_googlefontside2" => '',
	"mantra_sidefontsize" => "Default",
	"mantra_fontsubheader" => 'font-general',
	"mantra_googlefontsubheader" => 'Merriweather:400,700',
	"mantra_googlefontsubheader2" => '',
	"mantra_textalign" => "Default",
	"mantra_parmargin" => "1.5em",
	"mantra_parindent" => "0px",
	"mantra_headerindent" => "Disable",
	"mantra_lineheight" => "Default",
	"mantra_wordspace" => "Default",
	"mantra_letterspace" => "Default",

	"mantra_contentbg" => "#FFFFFF",
	"mantra_menubg" => "#FAFAFA",
	"mantra_s1bg" => "",
	"mantra_s2bg" => "",
	"mantra_backcolor" => "#444444",
	"mantra_headercolor" => "#333333",
	"mantra_prefootercolor" => "#222222",
	"mantra_footercolor" => "#171717",
	"mantra_titlecolor" => "#0D85CC",
	"mantra_descriptioncolor" => "#999999",
	"mantra_contentcolor" => "#555555",
	"mantra_linkscolor" => "#0D85CC",
	"mantra_hovercolor" => "#12a7ff",
	"mantra_headtextcolor" => "#444444",
	"mantra_headtexthover" => "#000000",
	"mantra_sideheadbackcolor" => "#444444",
	"mantra_sideheadtextcolor" => "#FFFFFF",

	"mantra_footerheader" => "#FFFFFF",
	"mantra_footertext" => "#666666",
	"mantra_footerhover" => "#888888",

	"mantra_breadcrumbs" => "Disable",
	"mantra_pagination" => "Enable",
	"mantra_caption" => "Light",
	"mantra_image" => "None",
	"mantra_pin" => "Pin2",
	"mantra_sidebullet" => "arrow_white",
	"mantra_metaback" => "Gray",
	"mantra_postseparator" => "Hide",
	"mantra_contentlist" => "Show",
	"mantra_pagetitle" => "Show",
	"mantra_categtitle" => "Show",
	"mantra_tables" => "Disable",
	"mantra_backtop" => "Enable",
	"mantra_comtext" => "Show",
	"mantra_comclosed" => "Hide everywhere",
	"mantra_comoff" => "Show",

	"mantra_postcomlink" => "Show",
	"mantra_postdate" => "Show",
	"mantra_posttime" => "Hide",
	"mantra_postauthor" => "Show",
	"mantra_postcateg" => "Show",
	"mantra_posttag" => "Show",
	"mantra_postbook" => "Show",
	"mantra_postmetas" => "Show",

	"mantra_excerpthome" => "Excerpt",
	"mantra_excerptsticky" => "Full Post",
	"mantra_excerptarchive" => "Excerpt",
	"mantra_excerptwords" => "50",
	"mantra_magazinelayout" => "Disable",
	"mantra_excerptdots" => "...",
	"mantra_excerptcont" => " Continue reading",
	"mantra_excerpttags" => "Disable",

	"mantra_fpost" => "Enable",
	"mantra_fpostlink" => "1",
	"mantra_fauto" => "Disable",
	"mantra_falign" => "Left",
	"mantra_fwidth" => "250",
	"mantra_fheight" => "150",
	"mantra_fcrop" => "",
	"mantra_fheader" => "Disable",

	"mantra_social1" => "Facebook",
	"mantra_social2" => "https://www.facebook.com/Profile_or_Page",
	"mantra_social3" => "Twitter",
	"mantra_social4" => "https://twitter.com/username",
	"mantra_social5" => "RSS",
	"mantra_social6" => "http://mydomain.tld/feed/",
	"mantra_social7" => "",
	"mantra_social8" => "",
	"mantra_social9" => "",
	"mantra_social10" => "",
	"mantra_socialsdisplay0" => "1",
	"mantra_socialsdisplay1" => "",
	"mantra_socialsdisplay2" => "1",
	"mantra_socialsdisplay3" => "1",

	"mantra_copyright" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla massa diam, tempus a finibus et, euismod nec arcu. Praesent ultrices massa at molestie facilisis.",
	"mantra_customcss" => "/* Mantra Custom CSS */  ",
	"mantra_customjs" => "",
	"mantra_editorstyle" => 1,
	
);

// FIN
